ProofV2

Struct ProofV2 

#[repr(C)]
pub struct ProofV2 { pub resource: Pubkey, pub authority: Pubkey, pub balance: u64, pub challenge: [u8; 32], pub last_hash: [u8; 32], pub last_hash_at: i64, pub last_stake_at: i64, pub miner: Pubkey, pub total_hashes: u64, pub total_rewards: u64, pub equipped_tool: Pubkey, }

Fields

resource: Pubkey

The resource mint this proof is for.

authority: Pubkey

The signer authorized to use this proof.

balance: u64

The quantity of tokens this miner has staked or earned.

challenge: [u8; 32]

The current mining challenge.

last_hash: [u8; 32]

The last hash the miner provided.

last_hash_at: i64

The last time this account provided a hash.

last_stake_at: i64

The last time stake was deposited into this account.

miner: Pubkey

The keypair which has permission to submit hashes for mining.

total_hashes: u64

The total lifetime hashes provided by this miner.

total_rewards: u64

The total lifetime rewards distributed to this miner.

equipped_tool: Pubkey

The tool equipped by the miner.

Implementations

Source

impl ProofV2

pub fn to_bytes(&self) -> &[u8]